@@ -1,5 +1,4 @@
 use std::fs::File;
-use std::sync::Arc;
 
 use arrow2::error::Result;
 use arrow2::io::parquet::read;
@@ -11,7 +10,7 @@ fn main() -> Result<()> {
     let file_path = &args[1];
 
     let reader = File::open(file_path)?;
-    let reader = read::RecordReader::try_new(reader, None, None, Arc::new(|_, _| true), None)?;
+    let reader = read::RecordReader::try_new(reader, None, None, None, None)?;
 
     for maybe_batch in reader {
         let batch = maybe_batch?;
