@@ -1,8 +1,10 @@
 use std::{convert::TryInto, slice::ChunksExact};
 
+use crate::trusted_len::TrustedLen;
+
 use super::{BitChunk, BitChunkIterExact};
 
-/// An iterator over a [`BitChunk`] from a slice of bytes.
+/// An iterator over a slice of bytes in [`BitChunk`]s.
 #[derive(Debug)]
 pub struct BitChunksExact<'a, T: BitChunk> {
     iter: ChunksExact<'a, u8>,
@@ -11,20 +13,17 @@ pub struct BitChunksExact<'a, T: BitChunk> {
 }
 
 impl<'a, T: BitChunk> BitChunksExact<'a, T> {
+    /// Creates a new [`BitChunksExact`].
     #[inline]
     pub fn new(slice: &'a [u8], len: usize) -> Self {
+        assert!(len <= slice.len() * 8);
         let size_of = std::mem::size_of::<T>();
 
-        let chunks = &slice[..len / 8];
+        let split = (len / 8 / size_of) * size_of;
+        let chunks = &slice[..split];
+        let remainder = &slice[split..];
         let iter = chunks.chunks_exact(size_of);
 
-        let start = if slice.len() > size_of {
-            slice.len() - size_of
-        } else {
-            0
-        };
-        let remainder = &slice[start..];
-
         Self {
             iter,
             remainder,
@@ -32,16 +31,19 @@ impl<'a, T: BitChunk> BitChunksExact<'a, T> {
         }
     }
 
+    /// Returns the number of chunks of this iterator
     #[inline]
     pub fn len(&self) -> usize {
         self.iter.len()
     }
 
+    /// Returns whether there are still elements in this iterator
     #[inline]
     pub fn is_empty(&self) -> bool {
         self.len() == 0
     }
 
+    /// Returns the remaining [`BitChunk`]. It is zero iff `len / 8 == 0`.
     #[inline]
     pub fn remainder(&self) -> T {
         let remainder_bytes = self.remainder;
@@ -80,6 +82,8 @@ impl<T: BitChunk> Iterator for BitChunksExact<'_, T> {
     }
 }
 
+unsafe impl<T: BitChunk> TrustedLen for BitChunksExact<'_, T> {}
+
 impl<T: BitChunk> BitChunkIterExact<T> for BitChunksExact<'_, T> {
     #[inline]
     fn remainder(&self) -> T {
