@@ -1,12 +1,11 @@
 #![deny(missing_docs)]
-//! Contains containers for all Arrow sized types (e.g. `i32`),
-//! [`Buffer`] and [`MutableBuffer`].
+//! Contains [`Buffer`] and [`MutableBuffer`], containers for all Arrow
+//! physical types (e.g. i32, f64).
 
 mod immutable;
 mod mutable;
 
 pub(crate) mod bytes;
-pub(crate) mod util;
 
 pub use immutable::Buffer;
 pub use mutable::MutableBuffer;
