@@ -2,7 +2,7 @@ use crate::array::*;
 use crate::bitmap::Bitmap;
 use crate::datatypes::PhysicalType;
 
-fn validity_size(validity: &Option<Bitmap>) -> usize {
+fn validity_size(validity: Option<&Bitmap>) -> usize {
     validity.as_ref().map(|b| b.as_slice().0.len()).unwrap_or(0)
 }
 
@@ -109,28 +109,10 @@ pub fn estimated_bytes_size(array: &dyn Array) -> usize {
         Dictionary(key_type) => with_match_physical_dictionary_key_type!(key_type, |$T| {
             dyn_dict!(array, $T)
         }),
-    }
-}
-
-#[cfg(test)]
-mod tests {
-    use super::*;
-
-    #[test]
-    fn primitive() {
-        let a = Int32Array::from_slice(&[1, 2, 3, 4, 5]);
-        assert_eq!(5 * std::mem::size_of::<i32>(), estimated_bytes_size(&a));
-    }
-
-    #[test]
-    fn boolean() {
-        let a = BooleanArray::from_slice(&[true]);
-        assert_eq!(1, estimated_bytes_size(&a));
-    }
-
-    #[test]
-    fn utf8() {
-        let a = Utf8Array::<i32>::from_slice(&["aaa"]);
-        assert_eq!(3 + 2 * std::mem::size_of::<i32>(), estimated_bytes_size(&a));
+        Map => {
+            let array = array.as_any().downcast_ref::<MapArray>().unwrap();
+            let offsets = array.offsets().len() * std::mem::size_of::<i32>();
+            offsets + estimated_bytes_size(array.field().as_ref()) + validity_size(array.validity())
+        }
     }
 }
