@@ -51,6 +51,12 @@ impl From<std::str::Utf8Error> for ArrowError {
     }
 }
 
+impl From<simdutf8::basic::Utf8Error> for ArrowError {
+    fn from(error: simdutf8::basic::Utf8Error) -> Self {
+        ArrowError::External("".to_string(), Box::new(error))
+    }
+}
+
 impl Display for ArrowError {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self {
