@@ -1,3 +1,4 @@
+#![deny(missing_docs)]
 //! Transfer data between the Arrow memory format and CSV (comma-separated values).
 
 use crate::error::ArrowError;
@@ -16,5 +17,9 @@ impl From<chrono::ParseError> for ArrowError {
     }
 }
 
+#[cfg(feature = "io_csv_read")]
+#[cfg_attr(docsrs, doc(cfg(feature = "io_csv_read")))]
 pub mod read;
+#[cfg(feature = "io_csv_write")]
+#[cfg_attr(docsrs, doc(cfg(feature = "io_csv_write")))]
 pub mod write;
