@@ -20,3 +20,5 @@ mod dictionary;
 pub use dictionary::*;
 mod union;
 pub use union::*;
+mod map;
+pub use map::*;
