@@ -1,5 +1,6 @@
-//! Interact with different formats such as Arrow, CSV, parquet, etc.
-#[cfg(feature = "io_csv")]
+//! Contains modules to interface with other formats such as [`csv`],
+//! [`parquet`], [`json`], [`ipc`], [`mod@print`] and [`avro`].
+#[cfg(any(feature = "io_csv_read", feature = "io_csv_write"))]
 #[cfg_attr(docsrs, doc(cfg(feature = "io_csv")))]
 pub mod csv;
 
@@ -19,6 +20,10 @@ pub mod json_integration;
 #[cfg_attr(docsrs, doc(cfg(feature = "io_parquet")))]
 pub mod parquet;
 
+#[cfg(feature = "io_avro")]
+#[cfg_attr(docsrs, doc(cfg(feature = "io_avro")))]
+pub mod avro;
+
 #[cfg(feature = "io_print")]
 #[cfg_attr(docsrs, doc(cfg(feature = "io_print")))]
 pub mod print;
