@@ -1,3 +1,4 @@
+//! APIs exposing `parquet2`'s statistics as arrow's statistics.
 use crate::datatypes::DataType;
 use crate::error::ArrowError;
 use parquet2::schema::types::PhysicalType;
@@ -12,9 +13,12 @@ mod binary;
 pub use binary::*;
 mod boolean;
 pub use boolean::*;
+mod fixlen;
+pub use fixlen::*;
 
-/// Trait denoting a deserialized parquet statistics (into arrow).
+/// Trait representing a deserialized parquet statistics into arrow.
 pub trait Statistics: std::fmt::Debug {
+    /// returns the [`DataType`] of the statistics.
     fn data_type(&self) -> &DataType;
 }
 
@@ -68,6 +72,10 @@ pub fn deserialize_statistics(stats: &dyn ParquetStatistics) -> Result<Box<dyn S
                 DataType::Float64,
             ))))
         }
+        PhysicalType::FixedLenByteArray(_) => {
+            let stats = stats.as_any().downcast_ref().unwrap();
+            fixlen::statistics_from_fix_len(stats, stats.descriptor.type_())
+        }
         _ => Err(ArrowError::NotYetImplemented(
             "Reading Fixed-len array statistics is not yet supported".to_string(),
         )),
