@@ -1,9 +1,13 @@
 use parquet2::{
-    compression::create_codec, encoding::Encoding, metadata::ColumnDescriptor,
-    page::CompressedDataPage, write::WriteOptions,
+    compression::create_codec,
+    encoding::Encoding,
+    metadata::ColumnDescriptor,
+    page::CompressedDataPage,
+    statistics::{serialize_statistics, deserialize_statistics, ParquetStatistics},
+    write::WriteOptions,
 };
 
-use super::utils;
+use super::{binary::ord_binary, utils};
 use crate::{
     array::{Array, FixedSizeBinaryArray},
     error::Result,
@@ -54,6 +58,12 @@ pub fn array_to_page(
         buffer
     };
 
+    let statistics = if options.write_statistics {
+        build_statistics(array, descriptor.clone())
+    } else {
+        None
+    };
+
     utils::build_plain_page(
         buffer,
         array.len(),
@@ -61,9 +71,34 @@ pub fn array_to_page(
         uncompressed_page_size,
         0,
         definition_levels_byte_length,
-        None,
+        statistics,
         descriptor,
         options,
         Encoding::Plain,
     )
 }
+
+pub(super) fn build_statistics(
+    array: &FixedSizeBinaryArray,
+    descriptor: ColumnDescriptor,
+) -> Option<ParquetStatistics> {
+    let pq_statistics = &ParquetStatistics {
+        max: None,
+        min: None,
+        null_count: Some(array.null_count() as i64),
+        distinct_count: None,
+        max_value: array
+            .iter()
+            .flatten()
+            .max_by(|x, y| ord_binary(x, y))
+            .map(|x| x.to_vec()),
+        min_value: array
+            .iter()
+            .flatten()
+            .min_by(|x, y| ord_binary(x, y))
+            .map(|x| x.to_vec()),
+    };
+    deserialize_statistics(pq_statistics,descriptor).map(
+        |e| serialize_statistics(&*e)
+    ).ok()
+}
