@@ -1,10 +1,12 @@
-//! Doc provided by README
-
+#![doc = include_str!("doc/lib.md")]
+// So that we have more control over what is `unsafe` inside an `unsafe` block
+#![allow(unused_unsafe)]
 #![cfg_attr(docsrs, feature(doc_cfg))]
 
-pub mod alloc;
 #[macro_use]
 pub mod array;
+#[cfg(feature = "cache_aligned")]
+mod alloc;
 pub mod bitmap;
 pub mod buffer;
 mod endianess;
@@ -12,6 +14,8 @@ pub mod error;
 pub mod scalar;
 pub mod trusted_len;
 pub mod types;
+#[cfg(feature = "cache_aligned")]
+mod vec;
 
 #[cfg(feature = "compute")]
 #[cfg_attr(docsrs, doc(cfg(feature = "compute")))]
@@ -19,7 +23,6 @@ pub mod compute;
 pub mod io;
 pub mod record_batch;
 pub mod temporal_conversions;
-pub use alloc::total_allocated_bytes;
 
 pub mod datatypes;
 
